@@ -834,7 +834,7 @@ Returns t if checkout was successful, nil otherwise."
 ;; version of vc was loaded:
 (defalias 'vc-sensitize-menu 'vc-menu-filter)
 
-(if vc-elucidated
+(if (and (fboundp 'add-submenu) (not (featurep 'infodock)) vc-elucidated)
     (progn
       (add-submenu '("Tools") (append (list "Version Control") vc-default-menu))
 ;; Only add the hook if the :filter method is unavailable.  I don't know which
